@@ -1,24 +1,34 @@
 from hestia_earth.schema import SchemaType, CycleFunctionalUnitMeasure, SiteSiteType, TermTermType
-from hestia_earth.utils.tools import flatten
+from hestia_earth.utils.tools import flatten, list_sum
 from hestia_earth.utils.date import diff_in_days, is_in_days
 from hestia_earth.utils.api import find_node
 
 from hestia_earth.validation.utils import _find_linked_node, _value_average, _list_sum_terms
 from .shared import (
-    validate_dates, validate_list_dates, validate_date_lt_today, validate_list_duplicates, validate_list_min_max,
+    validate_dates, validate_list_dates, validate_date_lt_today, validate_list_min_max,
     validate_list_term_percent, validate_linked_source_privacy, validate_list_dates_length, validate_list_date_lt_today,
-    validate_properties_default_value
+    validate_properties_default_value, validate_list_model, validate_list_model_config, validate_list_dates_format,
+    validate_list_duplicate_values
 )
+from .input import validate_must_include_id
 from .practice import validate_cropResidueManagement, validate_longFallowPeriod
 from .product import validate_economicValueShare, validate_value as validate_product_value
 from .data_completeness import validate_dataCompleteness
-from .transformation import validate_previous_transformation
+from .transformation import validate_previous_transformation, validate_first_transformation
 
 
 SITE_TYPES_RESTRICTED = [
     SiteSiteType.CROPLAND.value,
     SiteSiteType.PERMANENT_PASTURE.value
 ]
+PRODUCTS_MODEL_CONFIG = {
+    'aboveGroundCropResidueTotal': {
+        'level': 'warning',
+        'model': 'ipcc2006',
+        'delta': 0.5,
+        'resetDataCompleteness': True
+    }
+}
 
 
 def validate_cycle_dates(cycle: dict):
@@ -93,6 +103,42 @@ def validate_crop_residue_completeness(cycle: dict, site: dict):
     return data_completeness is False or site_type not in SITE_TYPES_RESTRICTED or validate_sum()
 
 
+def validate_siteDuration(cycle: dict):
+    cycleDuration = cycle.get('cycleDuration')
+    siteDuration = cycle.get('siteDuration')
+    has_multiple_sites = len(cycle.get('otherSites', [])) > 0
+    return cycleDuration is None or siteDuration is None or (cycleDuration != siteDuration or {
+        'level': 'error',
+        'dataPath': '.siteDuration',
+        'message': 'must not be equal to cycleDuration'
+    } if has_multiple_sites else cycleDuration == siteDuration or {
+        'level': 'error',
+        'dataPath': '.siteDuration',
+        'message': 'must be equal to cycleDuration'
+    })
+
+
+def validate_otherSites_length(cycle: dict):
+    otherSites = cycle.get('otherSites', [])
+    otherSitesDuration = cycle.get('otherSitesDuration', [])
+    return len(otherSites) == len(otherSitesDuration) or {
+        'level': 'error',
+        'dataPath': '.otherSitesDuration',
+        'message': 'must have the same length as otherSites'
+    }
+
+
+def validate_otherSites_cycleDuration(cycle: dict):
+    cycleDuration = cycle.get('cycleDuration', 0)
+    siteDuration = cycle.get('siteDuration')
+    total_duration = list_sum([siteDuration or 0] + cycle.get('otherSitesDuration', [0]))
+    return siteDuration is None or cycleDuration == total_duration or {
+        'level': 'error',
+        'dataPath': '.cycleDuration',
+        'message': 'must be equal to the sum of siteDuration and otherSitesDuration'
+    }
+
+
 def validate_cycle(cycle: dict, nodes=[]):
     """
     Validates a single `Cycle`.
@@ -116,40 +162,31 @@ def validate_cycle(cycle: dict, nodes=[]):
         validate_date_lt_today(cycle, 'endDate'),
         validate_linked_source_privacy(cycle, 'defaultSource', nodes),
         validate_cycleDuration(cycle) if _should_validate_cycleDuration(cycle) else True,
-        validate_dataCompleteness(cycle.get('dataCompleteness', {}), site) if 'dataCompleteness' in cycle else True
+        validate_dataCompleteness(cycle.get('dataCompleteness', {}), site) if 'dataCompleteness' in cycle else True,
+        validate_siteDuration(cycle),
+        validate_otherSites_length(cycle),
+        validate_otherSites_cycleDuration(cycle)
     ]) + flatten([
+        validate_list_model(cycle, 'emissions'),
         validate_list_dates(cycle, 'emissions'),
+        validate_list_dates_format(cycle, 'emissions'),
         validate_list_min_max(cycle, 'emissions'),
         validate_list_term_percent(cycle, 'emissions'),
         validate_list_dates_length(cycle, 'emissions'),
         validate_list_date_lt_today(cycle, 'emissions', ['startDate', 'endDate']),
-        validate_list_duplicates(cycle, 'emissions', [
-            'term.@id',
-            'inputs.@id',
-            'source.id',
-            'methodModel.@id',
-            'methodModelDescription',
-            'startDate',
-            'endDate',
-            'dates'
-        ]),
         validate_properties_default_value(cycle, 'emissions', 'properties')
     ] if len(cycle.get('emissions', [])) > 0 else []) + flatten([
+        validate_list_dates(cycle, 'inputs'),
+        validate_list_dates_format(cycle, 'inputs'),
         validate_list_dates_length(cycle, 'inputs'),
         validate_list_date_lt_today(cycle, 'inputs', ['startDate', 'endDate']),
         validate_list_min_max(cycle, 'inputs'),
         validate_list_term_percent(cycle, 'inputs'),
-        validate_list_duplicates(cycle, 'inputs', [
-            'term.@id',
-            'source.id',
-            'methodModelDescription',
-            'operation',
-            'startDate',
-            'endDate',
-            'dates'
-        ]),
-        validate_properties_default_value(cycle, 'inputs', 'properties')
+        validate_properties_default_value(cycle, 'inputs', 'properties'),
+        validate_must_include_id(cycle['inputs'])
     ] if len(cycle.get('inputs', [])) > 0 else []) + flatten([
+        validate_list_dates(cycle, 'products'),
+        validate_list_dates_format(cycle, 'products'),
         validate_list_dates_length(cycle, 'products'),
         validate_list_date_lt_today(cycle, 'products', ['startDate', 'endDate']),
         validate_list_min_max(cycle, 'products'),
@@ -158,21 +195,24 @@ def validate_cycle(cycle: dict, nodes=[]):
         validate_sum_aboveGroundCropResidue(cycle.get('products')),
         validate_product_value(cycle.get('products')),
         validate_properties_default_value(cycle, 'products', 'properties'),
-        validate_crop_residue_completeness(cycle, site) if 'dataCompleteness' in cycle and site else True
+        validate_crop_residue_completeness(cycle, site) if 'dataCompleteness' in cycle and site else True,
+        validate_list_model_config(cycle, 'products', PRODUCTS_MODEL_CONFIG)
     ] if len(cycle.get('products', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'practices'),
+        validate_list_dates_format(cycle, 'practices'),
         validate_list_date_lt_today(cycle, 'practices', ['startDate', 'endDate']),
         validate_list_min_max(cycle, 'practices'),
         validate_list_term_percent(cycle, 'practices'),
         validate_cropResidueManagement(cycle.get('practices')),
         validate_longFallowPeriod(cycle.get('practices')),
-        validate_properties_default_value(cycle, 'practices', 'properties')
+        validate_properties_default_value(cycle, 'practices', 'properties'),
+        validate_list_duplicate_values(cycle, 'practices', 'term.termType', TermTermType.EXCRETAMANAGEMENT.value)
     ] if len(cycle.get('practices', [])) > 0 else []) + flatten([
         validate_functionalUnitMeasure(cycle, site)
     ] if 'functionalUnitMeasure' in cycle and site else []) + flatten([
+        validate_list_dates(cycle, 'transformations'),
+        validate_list_dates_format(cycle, 'transformations'),
         validate_list_date_lt_today(cycle, 'transformations', ['startDate', 'endDate']),
         validate_previous_transformation(cycle.get('transformations')),
-        validate_list_duplicates(cycle, 'transformations', [
-            'term.@id'
-        ])
+        validate_first_transformation(cycle.get('transformations'))
     ] if len(cycle.get('transformations', [])) > 0 in cycle else [])
