@@ -1,8 +1,9 @@
 from hestia_earth.utils.tools import flatten
 
 from .shared import (
-    validate_list_duplicates, validate_list_min_max, validate_region, validate_country,
-    validate_list_term_percent, validate_linked_source_privacy, validate_date_lt_today
+    validate_list_duplicates, validate_list_min_max, validate_region_in_country, validate_country, validate_is_region,
+    validate_list_term_percent, validate_linked_source_privacy, validate_date_lt_today,
+    validate_list_model
 )
 
 
@@ -27,8 +28,10 @@ def validate_impact_assessment(impact_assessment: dict, nodes=[]):
         validate_date_lt_today(impact_assessment, 'endDate'),
         validate_linked_source_privacy(impact_assessment, 'source', nodes),
         validate_country(impact_assessment) if 'country' in impact_assessment else True,
-        validate_region(impact_assessment) if 'region' in impact_assessment else True
+        validate_is_region(impact_assessment) if 'region' in impact_assessment else True,
+        validate_region_in_country(impact_assessment) if 'region' in impact_assessment else True
     ] + flatten([
+        validate_list_model(impact_assessment, 'impacts'),
         validate_list_min_max(impact_assessment, 'impacts'),
         validate_list_term_percent(impact_assessment, 'impacts'),
         validate_list_duplicates(impact_assessment, 'impacts', [
