@@ -3,7 +3,7 @@ from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 from hestia_earth.utils.tools import non_empty_list, safe_parse_float, flatten
 
-from hestia_earth.validation.utils import _filter_list_errors, _list_has_props, _value_range_error, _value_average
+from hestia_earth.validation.utils import _filter_list_errors, _value_range_error, _value_average
 
 
 SOIL_TEXTURE_IDS = ['sandContent', 'siltContent', 'clayContent']
@@ -83,25 +83,22 @@ def validate_soilTexture(measurements: list):
 
 
 def validate_depths(measurements: list):
-    def validate(values: list):
-        index = values[0]
-        measurement = values[1]
-        return measurement['depthUpper'] < measurement['depthLower'] or {
+    def validate(values: tuple):
+        index, measurement = values
+        return measurement.get('depthUpper', 0) < measurement.get('depthLower', 1) or {
             'level': 'error',
             'dataPath': f".measurements[{index}].depthLower",
             'message': 'must be greater than depthUpper'
         }
 
-    results = list(map(validate, enumerate(_list_has_props(measurements, ['depthUpper', 'depthLower']))))
-    return _filter_list_errors(results)
+    return _filter_list_errors(map(validate, enumerate(measurements)))
 
 
 def validate_value_min_max(measurements: list):
     lookup = download_lookup('measurement.csv', True)
 
-    def validate(values: list):
-        index = values[0]
-        measurement = values[1]
+    def validate(values: tuple):
+        index, measurement = values
         term_id = measurement.get('term', {}).get('@id')
         mininum = safe_parse_float(get_table_value(lookup, 'termid', term_id, 'minimum'), None)
         maximum = safe_parse_float(get_table_value(lookup, 'termid', term_id, 'maximum'), None)
@@ -126,9 +123,8 @@ def validate_term_unique(measurements: list):
     def count_same_term(term_id: str):
         return len(list(filter(lambda x: x.get('term', {}).get('@id') == term_id, measurements)))
 
-    def validate(values: list):
-        index = values[0]
-        measurement = values[1]
+    def validate(values: tuple):
+        index, measurement = values
         term_id = measurement.get('term', {}).get('@id')
         unique = get_table_value(lookup, 'termid', term_id, 'onemeasurementpersite')
         unique = False if unique is None or unique == '-' else bool(unique)
