@@ -14,9 +14,8 @@ def validate_economicValueShare(products: list):
 
 
 def validate_value(products: list):
-    def validate(values):
-        index = values[0]
-        product = values[1]
+    def validate(values: tuple):
+        index, product = values
         return len(product.get('value', [])) > 0 or {
             'level': 'warning',
             'dataPath': f".products[{index}].value",
