@@ -1,6 +1,7 @@
-from functools import reduce
 import os
 from typing import List
+from concurrent.futures import ThreadPoolExecutor
+from functools import reduce
 import re
 from hestia_earth.utils.tools import flatten, non_empty_list, safe_parse_float, list_sum
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
@@ -447,7 +448,9 @@ def validate_list_model(node: dict, list_key: str) -> list:
     """
     run = os.environ.get('VALIDATE_MODELS', 'true') == 'true'
     nodes = node.get(list_key, [])
-    return _filter_list_errors(map(_validate_list_model(node, list_key), enumerate(nodes))) if run else []
+    with ThreadPoolExecutor() as executor:
+        errors = list(executor.map(_validate_list_model(node, list_key), enumerate(nodes))) if run else []
+    return _filter_list_errors(errors)
 
 
 def _reset_dataCompleteness(node: dict):
@@ -511,4 +514,6 @@ def validate_list_model_config(node: dict, list_key: str, conf: dict):
     """
     run = os.environ.get('VALIDATE_MODELS', 'true') == 'true'
     nodes = node.get(list_key, [])
-    return _filter_list_errors(map(_validate_list_model_config(node, list_key, conf), enumerate(nodes))) if run else []
+    with ThreadPoolExecutor() as executor:
+        errors = list(executor.map(_validate_list_model_config(node, list_key,  conf), enumerate(nodes))) if run else []
+    return _filter_list_errors(errors)
