@@ -1,10 +1,10 @@
 from hestia_earth.schema import SiteSiteType
 from hestia_earth.utils.tools import flatten
 
-from hestia_earth.validation.gee import is_enabled, fetch_data
+from hestia_earth.validation.gee import fetch_data
 from .shared import (
-    validate_dates, validate_list_dates, validate_list_duplicates, validate_list_min_max,
-    validate_region, validate_country, validate_coordinates, need_validate_coordinates,
+    validate_dates, validate_list_dates, validate_list_dates_format, validate_list_min_max,
+    validate_region_in_country, validate_country, validate_is_region, validate_coordinates, need_validate_coordinates,
     validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy,
     validate_list_date_lt_today, validate_date_lt_today, validate_properties_default_value
 )
@@ -16,7 +16,8 @@ from .practice import validate_cropResidueManagement, validate_longFallowPeriod
 INLAND_TYPES = [
     SiteSiteType.CROPLAND.value,
     SiteSiteType.PERMANENT_PASTURE.value,
-    SiteSiteType.POND.value,
+    SiteSiteType.RIVER_OR_STREAM.value,
+    SiteSiteType.LAKE.value,
     SiteSiteType.ANIMAL_HOUSING.value,
     SiteSiteType.FACTORY.value,
     SiteSiteType.FOREST.value,
@@ -88,35 +89,30 @@ def validate_site(site: dict, nodes=[]):
         validate_date_lt_today(site, 'endDate'),
         validate_linked_source_privacy(site, 'defaultSource', nodes),
         validate_siteType(site) if need_validate_coordinates(site) else True,
-        validate_country(site) if is_enabled() and 'country' in site else True,
-        validate_region(site) if is_enabled() and 'region' in site else True,
+        validate_country(site) if 'country' in site else True,
+        validate_is_region(site) if 'region' in site else True,
+        validate_region_in_country(site) if 'region' in site else True,
         validate_coordinates(site) if validate_site_coordinates(site) else True,
         validate_area(site) if need_validate_area(site) else True
     ] + flatten([
         validate_list_dates(site, 'measurements'),
+        validate_list_dates_format(site, 'measurements'),
         validate_list_date_lt_today(site, 'measurements', ['startDate', 'endDate']),
         validate_list_min_max(site, 'measurements'),
         validate_list_term_percent(site, 'measurements'),
         validate_soilTexture(site.get('measurements')),
         validate_depths(site.get('measurements')),
         validate_value_min_max(site.get('measurements')),
-        validate_list_duplicates(site, 'measurements', [
-            'term.@id',
-            'methodModel.@id',
-            'methodModelDescription',
-            'startDate',
-            'endDate',
-            'depthUpper',
-            'depthLower'
-        ]),
         validate_term_unique(site.get('measurements')),
         validate_properties_default_value(site, 'measurements', 'properties')
     ] if 'measurements' in site else []) + flatten([
         validate_list_dates(site, 'infrastructure'),
+        validate_list_dates_format(site, 'infrastructure'),
         validate_list_date_lt_today(site, 'infrastructure', ['startDate', 'endDate']),
         validate_lifespan(site.get('infrastructure'))
     ] if 'infrastructure' in site else []) + flatten([
         validate_list_dates(site, 'practices'),
+        validate_list_dates_format(site, 'practices'),
         validate_list_date_lt_today(site, 'practices', ['startDate', 'endDate']),
         validate_list_min_max(site, 'practices'),
         validate_list_term_percent(site, 'practices'),
